from random import randint
            
a = ['quiz', 'pynbs']

#App Code:
def quiz():
    n1 = randint(1,10)
    n2 = randint(1,10)
    answer = input('What is '+str(n1)+'x'+str(n2)+'? ')
    if(answer==str(n1*n2)):
        print('Correct!')
        app(a)
    else:
        print('Incorrect!')
        app(a)
def pynbs():
    prnt = input()
    print(prnt)
    app(a)
#App Code End
def app(a):
    openapp = input('What app do you want to open? ')
    if openapp in a:
        method_name = openapp # set by the command line options
        possibles = globals().copy()
        possibles.update(locals())
        method = possibles.get(method_name)
        method()
#User Stuff
def mart():
    print('Welcome User!')
    an = len(a)
    print('Apps Installed:')
    for i in range(0, an):
        print(' '+a[i])
    app(a)


import os
from User import *
from Admin import *

#A Very Simple Sign In System
users = ['Admin', 'User']
m = 'pass'
d = 'pass'
w = 'pass'
k = 'pass'

def passw():
    passw = input('What is your password? ')
    for i in range(0, 4):
        if name==users[i]:
            if users[i]=='User':
                mart()
            else:
                if users[i]=='Admin':
                    wart()
                
name = input('What is your username? ')
if name in users:
    print()
    passw()
else:
    print('ERROR: User not defined')




from setuptools import setup
__project__ = "SwanOS"
__version__ = "0.0.3"
__description__ = "A Very Simple Python OS"
__packages__ = ["os"]
__classifiers__ = [
    "Programming Language :: Python :: 3",
]
__author_email__ = 'forsbergw82@gmail.com'
setup(
    name = __project__,
    version = __version__,
    description = __description__,
    packages = __packages__,
    classifiers = __classifiers__,
    author_email = __author_email__,
)